@@ -9,7 +9,6 @@ from . import shipment
 from . import stock
 from . import sale
 from . import configuration
-from . import log
 from . import manifest
 from . import location
 from . import package
@@ -24,22 +23,18 @@ def register():
         carrier.Carrier,
         carrier.Service,
         carrier.CarrierService,
-        carrier.BoxType,
-        carrier.CarrierBoxType,
+        carrier.CarrierPackageType,
         ir.Cron,
-        log.CarrierLog,
         party.Address,
         tracking.ShipmentTracking,
         manifest.ShippingManifest,
         stock.StockMove,
         package.Package,
+        package.PackageType,
         sale.Sale,
         sale.SaleLine,
         sale.ApplyShippingStart,
         sale.ApplyShippingSelectRate,
-        shipment.GenerateShippingLabelMessage,
-        shipment.SelectShippingRate,
-        shipment.ShippingCarrierSelector,
         shipment.ShipmentOut,
         party.AddressValidationMsg,
         party.AddressValidationSuggestionView,
@@ -51,7 +46,6 @@ def register():
         depends=['sale_channel'],
         module='shipping', type_='model')
     Pool.register(
-        shipment.GenerateShippingLabel,
         party.AddressValidationWizard,
         sale.ReturnSale,
         sale.ApplyShipping,
