@@ -65,6 +65,37 @@ class ShipmentCarrierMixin(PackageMixin):
         "shipping.manifest", "Shipping Manifest", readonly=True, select=True
     )
 
+    @classmethod
+    def __setup__(cls):
+        super().__setup__()
+        cls.carrier_service.states = {
+            'readonly': Eval('state') == 'done',
+        }
+        cls.packages.context = {'carrier': Eval('carrier')}
+        cls.packages.depends = ['carrier']
+
+        # Following fields are already there in customer shipment, have
+        # them in mixin so other shipment model can also use it.
+
+        #cls.carrier = fields.Many2One('carrier', 'Carrier', states={
+        #        'readonly': ~Eval('state').in_(['draft', 'waiting', 'assigned',
+        #                'packed']),
+        #        },
+        #    depends=['state'])
+        #cls.cost_currency = fields.Many2One('currency.currency',
+        #    'Cost Currency', states={
+        #        'invisible': ~Eval('carrier'),
+        #        'required': Bool(Eval('carrier')),
+        #        'readonly': ~Eval('state').in_(['draft', 'waiting', 'assigned',
+        #                'packed']),
+        #        }, depends=['carrier', 'state'])
+        #cls.cost = fields.Numeric('Cost',
+        #    digits=price_digits, states={
+        #        'invisible': ~Eval('carrier'),
+        #        'readonly': ~Eval('state').in_(['draft', 'waiting', 'assigned',
+        #                'packed']),
+        #        }, depends=['carrier', 'state'])
+
     @property
     def carrier_cost_moves(self):
         "Moves to use for carrier cost calculation"
@@ -125,54 +156,6 @@ class ShipmentCarrierMixin(PackageMixin):
             return self.weight_uom.digits
         return 2
 
-    @classmethod
-    def __setup__(cls):
-        super(ShipmentCarrierMixin, cls).__setup__()
-        cls.carrier_service.states = {
-            'readonly': Eval('state') == 'done',
-        }
-        cls._buttons.update({
-            'label_wizard': {
-                'invisible': Or(
-                    (~Eval('state').in_(['packed', 'done'])),
-                    (Bool(Eval('tracking_number')))
-                ),
-            },
-        })
-        # Following fields are already there in customer shipment, have
-        # them in mixin so other shipment model can also use it.
-
-        #cls.carrier = fields.Many2One('carrier', 'Carrier', states={
-        #        'readonly': ~Eval('state').in_(['draft', 'waiting', 'assigned',
-        #                'packed']),
-        #        },
-        #    depends=['state'])
-        #cls.cost_currency = fields.Many2One('currency.currency',
-        #    'Cost Currency', states={
-        #        'invisible': ~Eval('carrier'),
-        #        'required': Bool(Eval('carrier')),
-        #        'readonly': ~Eval('state').in_(['draft', 'waiting', 'assigned',
-        #                'packed']),
-        #        }, depends=['carrier', 'state'])
-        #cls.cost = fields.Numeric('Cost',
-        #    digits=price_digits, states={
-        #        'invisible': ~Eval('carrier'),
-        #        'readonly': ~Eval('state').in_(['draft', 'waiting', 'assigned',
-        #                'packed']),
-        #        }, depends=['carrier', 'state'])
-
-
-        cls.packages.context = {'carrier': Eval('carrier')}
-        cls.packages.depends = ['carrier']
-
-    @classmethod
-    @ModelView.button_action('shipping.wizard_generate_shipping_label')
-    def label_wizard(cls, shipments):
-        if len(shipments) == 0:
-            raise UserError(gettext('shipping.no_shipments'))
-        elif len(shipments) > 1:
-            raise UserError(gettext('shipping.too_many_shipments'))
-
     @classmethod
     def copy(cls, shipments, default=None):
         if default is None:
@@ -227,30 +210,19 @@ class ShipmentCarrierMixin(PackageMixin):
         if not silent:
             raise UserError(gettext('shipping.warehouse_address_missing'))
 
-    def allow_label_generation(self):
-        """
-        Shipment must be in the right states and tracking number must not
-        be present.
-        """
-        if self.state not in ('packed', 'done'):
-            raise UserError(gettext('shipping.invalid_state'))
-
-        if self.tracking_number:
-            raise UserError(gettext('shipping.tracking_number_already_present'))
-
-        return True
-
-    def _create_default_package(self, box_type=None):
+    def _create_default_package(self, package_type=None):
         """
         Create a single stock package for the whole shipment
         """
         Package = Pool().get('stock.package')
 
-        package, = Package.create([{
+        values = {
             'shipment': '%s,%d' % (self.__name__, self.id),
-            'box_type': box_type and box_type.id,
             'moves': [('add', self.carrier_cost_moves)],
-        }])
+            }
+        if package_type is not None:
+            values['type'] = package_type.id,
+        package, = Package.create([values])
         return package
 
     def get_shipping_rates(self, carriers=None, silent=False):
